@@ -583,11 +583,11 @@ __END__
 
 =head1 NAME
 
-Compress::BGZF::Reader
+Compress::BGZF::Reader - Performs blocked GZIP (BGZF) decompression
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
